class bughelper(object):
    def info(self):
        pass
    
    def data(self, content):
        bug = content["bug"]
        displayclues = content["clue"]
        text = ""
        if displayclues:
            for key in displayclues.keys():
                text += """  * %s
    """ % key
                if displayclues[key]:
                    for a in displayclues[key]:
                        text += """   * %s
    """ % a
        return """ * [http://launchpad.net/bugs/%s bug #%s] %s:
    %s""" % (bug.bugnumber, bug.bugnumber, bug.info, text)
    
   
class bugnumbers(object):
    def data(self,content):
        bug = content["bug"]
        return """||<rowstyle="background-color: ;"> [%s %s ] || %s/%s || %s ||""" %(bug.url, int(bug), bug.status, bug.importance, bug.summary)

